========================
Scrapinghub release tool
========================

Overview
========

A handy tool to prepare and release projects to Scrapy Cloud.

Requirements
============

* Python 2.7

Install
=======

::

    pip install shub-image

Documentation
=============

You can find the documentation `here <https://shub-image.readthedocs.io/en/latest/>`_.

